@@ -71,23 +71,27 @@ class FileExistsTestCase(UCTestCase):
                         "in '/labX' where 'X' is the lab number.")
 
 
-class FileContentsMatchTestCase(UCTestCase):
-    def count_file_matches(self, filename, match, path="/autograder/source/"):
-        """ Count how many time match matches the text in filename """
+class StringContentsMatchTestCase(UCTestCase):
+    def count_matches(self, contents, match):
+        """ Count how many time match matches contents"""
 
         try:
             regexp = re.compile(match, re.MULTILINE)
         except re.error as _:
             return -1
+        return len(regexp.findall(contents))
 
-        successful_open = False
+class FileContentsMatchTestCase(StringContentsMatchTestCase):
+    def count_file_matches(self, filename, match, path="/autograder/source/"):
+        """ Count how many time match matches the text in filename """
         file_contents = ""
-        with open(path + "/" + filename, "r") as file:
-            successful_open = True
-            file_contents = file.read()
-        if not successful_open:
+        try:
+            with open(path + "/" + filename, "r") as file:
+                file_contents = file.read()
+        except IOError as ioe:
             return -1
-        return len(regexp.findall(file_contents))
+        return self.count_matches(file_contents, match)
+
 
 class GoldenTestCase(UCTestCase):
     # Helper methods
